@@ -6,9 +6,23 @@ import fnmatch
 from flowtool.style import echo, colors
 from flowtool.execute import run_command
 from flowtool.style import debug
+
+from flowtool_git.common import local_repo
+from flowtool_git.common import short_status
+from flowtool_git.common import dirty_files
+
 from pylint.lint import Run
 
 
+def demo(*args, **kwd):
+    echo.bold('demo-hook:', local_repo().git_dir)
+    #echo.white('git status:')
+    for line in short_status():
+        if line.on_index != ' ':
+            echo.cyan(line.on_index, '', line.filename)
+        if line.untracked != ' ':
+            echo.yellow('', line.untracked, line.filename)
+
 def minimal_config_name(repo):
     return os.sep.join([
         os.path.dirname(repo.git_dir),
@@ -88,9 +102,8 @@ IGNORE_RECURSIVE = set([
     '.git', 'build', 'dist', 'test', 'tests', 'venv',
 ])
 
-def discover_lint_files(repo):
-    """ Return the list of files to check. """
 
+def find_all_py_files(repo):
     def ignore_location(loc, dirs, files):
         inside = loc.split(os.sep)
         shall_ignore = IGNORE_RECURSIVE.intersection(inside)
@@ -106,9 +119,15 @@ def discover_lint_files(repo):
             debug.magenta(loc, matches)
     return result
 
-from pylint.epylint import py_run
+
 MAX_FAILS = 5
 
+def discover_lint_files(repo):
+    """ Return the list of files to check. """
+    #return find_all_py_files()
+    return dirty_files()
+
+
 def pylint_minimal(*args, **kwd):
     """ Run pylint with a minimal config. """
     repo = git.Repo(search_parent_directories=True)
